@@ -138,7 +138,7 @@ class ANA():
 
         ar = self.channelData(spot, channel, backward, fill_empty=True).Value.values
         
-        sz = self.param.MapPixSize[spot]
+        sz = self.param.MapPixSize[spot-1]
         ar = ar.reshape((sz, sz)).copy()
         ar[::2] = np.fliplr(ar[::2])
 
@@ -192,7 +192,7 @@ class ANA():
         d = self.spotData(spots)
         dd = d[(d['Channel'] == channel) & (d['Backward'] == backward)]
         if fill_empty:
-            sz = self.param.MapPixSize[spots]
+            sz = self.param.MapPixSize[spots-1]
         
             ar = np.zeros(sz*sz) * np.nan
             ar[dd.Line.values] = dd.Value.values
